var indexSectionsWithContent =
{
  0: "_abcdefghilmnopqrstuvw~",
  1: "abcdefglmoprstuv",
  2: "o",
  3: "abcdefglmoprstv",
  4: "abcdefghilmnoprstuvw~",
  5: "_acdefghilmnoprstuv",
  6: "bcdefghilmpqrstvw",
  7: "cefmrstv",
  8: "cefgilmnpqrstv",
  9: "flpst"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "related"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Friends"
};

